@@ -1,7 +1,6 @@
 from collections.abc import Generator
 
 import cv2
-
 from opencvtools.img import Img
 
 
@@ -10,7 +9,7 @@ class Capture(Generator):
     Capture frames from webcam/stream as a generator.
     """
 
-    def __init__(self, src=0, width=None, height=None, threaded=False):
+    def __init__(self, src=0, width=None, height=None):
         self.cap = cv2.VideoCapture(src)
         if not self.cap.isOpened():
             raise IOError(f"Could not open {src}")
